==> yasm-8.x-1.4.tar.gz: yasm/src/Services/GroupsStatistics.php <==
<?php

namespace Drupal\yasm\Services;

use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\group\Entity\GroupInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Groups statistics class.
 */
class GroupsStatistics implements GroupsStatisticsInterface {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Entity manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $entityManager;

  /**
   * {@inheritdoc}
   */
  public function countContents(GroupInterface $group) {
    // Use static query for performance.
    $query = $this->connection
      ->query('SELECT count(id) as count FROM {group_content_field_data} WHERE gid = :id AND (type LIKE :node OR type LIKE :content)', [
        ':id'      => $group->id(),
        ':node'    => $group->getGroupType()->id() . '-group_node-%',
        ':content' => 'group_content_type_%',
      ]);
    $result = $query->fetchAll();

    return $result[0]->count;
  }

  /**
   * {@inheritdoc}
   */
  public function countContentsByBundle(GroupInterface $group) {
    // Use static query for performance.
    $query = $this->connection
      ->query('SELECT count(id) as count, type, MIN(entity_id) as entity_id FROM {group_content_field_data} WHERE gid = :id AND (type LIKE :node OR type LIKE :content) GROUP by type', [
        ':id'      => $group->id(),
        ':node'    => $group->getGroupType()->id() . '-group_node-%',
        ':content' => 'group_content_type_%',
      ]);
    $results = $query->fetchAll();

    if (!empty($results)) {
      foreach ($results as $result) {
        $type = 'content';
        if (!empty($result->entity_id)) {
          if ($entity = $this->entityManager->getStorage('node')->loadMultiple([$result->entity_id])) {
            $entity = reset($entity);
            $type = $entity->bundle();
          }
        }

        $count_types[$type] = [
          'type'  => ucfirst($type),
          'count' => $result->count,
        ];
      }
    }

    return $count_types;
  }

  /**
   * {@inheritdoc}
   */
  public function countMembers(GroupInterface $group) {
    // Use static query for performance.
    $query = $this->connection
      ->query('SELECT count(DISTINCT entity_id) as count FROM {group_content_field_data} WHERE gid = :id AND type = :type', [
        ':id' => $group->id(),
        ':type' => $group->getGroupType()->id() . '-group_membership',
      ]);
    $result = $query->fetchAll();

    return $result[0]->count;
  }

  /**
   * {@inheritdoc}
   */
  public function countMembersByRole(GroupInterface $group) {
    $query = $this->connection
      ->query('SELECT
          count(DISTINCT gd.entity_id) as count,
          gr.group_roles_target_id as role
        FROM {group_content__group_roles} gr
        INNER JOIN {group_content_field_data} gd
        ON gr.entity_id = gd.id
        WHERE gd.gid = :id
        AND gr.bundle = :type
        GROUP BY gr.group_roles_target_id', [
          ':id'   => $group->id(),
          ':type' => $group->getGroupType()->id() . '-group_membership',
        ]);
    $results = $query->fetchAll();

    $count_roles = [];
    if (!empty($results)) {

      $roles = $this->getGroupRoles();
      foreach ($results as $result) {
        $count_roles[$result->role] = [
          'role'  => isset($roles[$result->role]) ? $roles[$result->role] : $result->role,
          'count' => $result->count,
        ];
      }
    }

    return $count_roles;
  }

  /**
   * {@inheritdoc}
   */
  public function getGroupRoles() {
    $query = $this->connection
      ->query('SELECT group_roles_target_id as role FROM {group_content__group_roles}');
    $results = $query->fetchAll();

    $group_roles = [];
    if (!empty($results)) {
      foreach ($results as $result) {
        $role = $this->entityTypeManager->getStorage('group_role')->load($result->role);
        if (!empty($role)) {
          $group_roles[$result->role] = $role->label();
        }
      }
    }

    return $group_roles;
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(Connection $connection, EntityTypeManagerInterface $entityTypeManager, EntityManagerInterface $entityManager) {
    $this->connection = $connection;
    $this->entityTypeManager = $entityTypeManager;
    $this->entityManager = $entityManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('entity_type.manager'),
      $container->get('entity.manager')
    );
  }

}

==> yasm-8.x-1.5.tar.gz: yasm/src/Services/GroupsStatistics.php <==
<?php

namespace Drupal\yasm\Services;

use Drupal\Core\Database\Connection;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\group\Entity\GroupInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Groups statistics class.
 */
class GroupsStatistics implements GroupsStatisticsInterface {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Entity manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $entityManager;

  /**
   * {@inheritdoc}
   */
  public function countContents(GroupInterface $group) {
    // Use static query for performance.
    $query = $this->connection
      ->query('SELECT count(id) as count FROM {group_content_field_data} WHERE gid = :id AND (type LIKE :node OR type LIKE :content)', [
        ':id'      => $group->id(),
        ':node'    => $group->getGroupType()->id() . '-group_node-%',
        ':content' => 'group_content_type_%',
      ]);
    $result = $query->fetchAll();

    return $result[0]->count;
  }

  /**
   * {@inheritdoc}
   */
  public function countContentsByBundle(GroupInterface $group) {
    // Use static query for performance.
    $query = $this->connection
      ->query('SELECT count(id) as count, type, MIN(entity_id) as entity_id FROM {group_content_field_data} WHERE gid = :id AND (type LIKE :node OR type LIKE :content) GROUP by type', [
        ':id'      => $group->id(),
        ':node'    => $group->getGroupType()->id() . '-group_node-%',
        ':content' => 'group_content_type_%',
      ]);
    $results = $query->fetchAll();

    $count_types = [];
    if (!empty($results)) {
      foreach ($results as $result) {
        $type = 'content';
        if (!empty($result->entity_id)) {
          if ($entity = $this->entityManager->getStorage('node')->loadMultiple([$result->entity_id])) {
            $entity = reset($entity);
            $type = $entity->bundle();
          }
        }

        $count_types[$type] = [
          'type'  => ucfirst($type),
          'count' => $result->count,
        ];
      }
    }

    return $count_types;
  }

  /**
   * {@inheritdoc}
   */
  public function countMembers(GroupInterface $group) {
    // Use static query for performance.
    $query = $this->connection
      ->query('SELECT count(DISTINCT entity_id) as count FROM {group_content_field_data} WHERE gid = :id AND type = :type', [
        ':id' => $group->id(),
        ':type' => $group->getGroupType()->id() . '-group_membership',
      ]);
    $result = $query->fetchAll();

    return $result[0]->count;
  }

  /**
   * {@inheritdoc}
   */
  public function countMembersByRole(GroupInterface $group) {
    $query = $this->connection
      ->query('SELECT
          count(DISTINCT gd.entity_id) as count,
          gr.group_roles_target_id as role
        FROM {group_content__group_roles} gr
        INNER JOIN {group_content_field_data} gd
        ON gr.entity_id = gd.id
        WHERE gd.gid = :id
        AND gr.bundle = :type
        GROUP BY gr.group_roles_target_id', [
          ':id'   => $group->id(),
          ':type' => $group->getGroupType()->id() . '-group_membership',
        ]);
    $results = $query->fetchAll();

    $count_roles = [];
    if (!empty($results)) {

      $roles = $this->getGroupRoles();
      foreach ($results as $result) {
        $count_roles[$result->role] = [
          'role'  => isset($roles[$result->role]) ? $roles[$result->role] : $result->role,
          'count' => $result->count,
        ];
      }
    }

    return $count_roles;
  }

  /**
   * {@inheritdoc}
   */
  public function getGroupRoles() {
    $query = $this->connection
      ->query('SELECT group_roles_target_id as role FROM {group_content__group_roles}');
    $results = $query->fetchAll();

    $group_roles = [];
    if (!empty($results)) {
      foreach ($results as $result) {
        $role = $this->entityTypeManager->getStorage('group_role')->load($result->role);
        if (!empty($role)) {
          $group_roles[$result->role] = $role->label();
        }
      }
    }

    return $group_roles;
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(
    Connection $connection,
    EntityTypeManagerInterface $entityTypeManager,
    EntityManagerInterface $entityManager
  ) {
    $this->connection = $connection;
    $this->entityTypeManager = $entityTypeManager;
    $this->entityManager = $entityManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('entity_type.manager'),
      $container->get('entity.manager')
    );
  }

}
